sample_j_wrap: Sampling from 10-component Gaussian Mixture component...

View source: R/component_samplers.R

sample_j_wrapR Documentation

Sampling from 10-component Gaussian Mixture component described in Omori et al. 2007

Description

Samples from the conditional posterior distribution of the log(\chi^2) distribution by approximating it with the mixture Gaussian distribution described in Omori et al. 2007.

Usage

sample_j_wrap(Td, obs = NULL)

Arguments

Td

length of the vector

obs

Td x 1 vector for the data.

Value

Dataframe containing the posterior samples: mean and variance for the mixture component.

Note

When the obs is not not specified, the components are samples from the prior distribution.


dsp documentation built on July 17, 2026, 1:06 a.m.