t_create_loc: Initializer for location indices for filling in band-sparse...

View source: R/abco.R

t_create_locR Documentation

Initializer for location indices for filling in band-sparse matrix

Description

Create row and column indices for locations of symmetric band-sparse matrix. Starts with the locations of the diagonal, proceed with upper-diagonals, followed by lower-diagonals.

Usage

t_create_loc(len, D)

Arguments

len

length of the diagonal of the band-sparse matrix

D

number of super-diagonals to include for the band-sparse

Value

a list containing

  • the row indices r and

  • the column indices c


dsp documentation built on Aug. 21, 2025, 5:29 p.m.