| t_sampleEvolParams | R Documentation |
Compute one draw for each of the parameters in the thresholded dynamic shrinkage process
for the special case in which the shrinkage parameter kappa ~ Beta(alpha, beta)
with alpha = beta = 1/2.
t_sampleEvolParams(
omega,
evolParams,
D = 1,
sigma_e = 1,
lower_b,
upper_b,
loc,
prior_dhs_phi = c(20, 1),
alphaPlusBeta = 1
)
omega |
|
evolParams |
list of parameters to be updated (see Value below) |
D |
the degree of differencing (one or two) |
sigma_e |
the observation error standard deviation; for (optional) scaling purposes |
lower_b |
the lower bound in the uniform prior of the threshold variable |
upper_b |
the upper bound in the uniform prior of the threshold variable |
loc |
list of the row and column indices to fill in a band-sparse matrix |
prior_dhs_phi |
the parameters of the prior for the log-volatility AR(1) coefficient |
alphaPlusBeta |
For the symmetric prior kappa ~ Beta(alpha, beta) with alpha=beta, specify the sum [alpha + beta] |
List of relevant components:
the T evolution error standard deviations sigma_wt,
the T log-volatility ht,
the 1 log-vol unconditional mean(s) dhs_mean,
the 1 log-vol AR(1) coefficient(s) dhs_phi,
the 1 log-vol correction coefficient(s) dhs_phi2,
the T log-vol innovation standard deviations sigma_eta_t from the Polya-Gamma priors,
the 1 initial log-vol SD sigma_eta_0,
the 1 threshold parameter r
The priors induced by prior_dhs_phi all imply a stationary (log-) volatility process.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.