Estimate the location of non-zeros (signals) implied by horseshoe-type thresholding.
getNonZeros(post_evol_sigma_t2, post_obs_sigma_t2 = NULL)A vector (or matrix) of indices identifying the signals according to the horsehoe-type thresholding rule.
the Nsims x T or Nsims x T x p
matrix/array of posterior draws of the evolution error variances.
the Nsims x 1 or Nsims x T matrix of
posterior draws of the observation error variances.
Thresholding is based on kappa[t] > 1/2, where
kappa = 1/(1 + evol_sigma_t2/obs_sigma_t2), evol_sigma_t2 is the
evolution error variance, and obs_sigma_t2 is the observation error variance.
In particular, the decision rule is based on the posterior mean of kappa.