| t_create_loc | R Documentation |
Create row and column indices for locations of symmetric band-sparse matrix. Starts with the locations of the diagonal, proceed with upper-diagonals, followed by lower-diagonals.
t_create_loc(len, D)
len |
length of the diagonal of the band-sparse matrix |
D |
number of super-diagonals to include for the band-sparse |
a list containing
the row indices r and
the column indices c
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.